.. module:: mpl_toolkits.axes_grid1

Matplotlib axes_grid1 Toolkit
=============================

The matplotlib :mod:`mpl_toolkits.axes_grid1` toolkit is a collection of
helper classes to ease displaying multiple images in matplotlib.  While the
aspect parameter in matplotlib adjust the position of the single axes,
axes_grid1 toolkit provides a framework to adjust the position of
multiple axes according to their aspects.

See :ref:`axes_grid1_users-guide-index` for a guide on the usage of axes_grid1.

.. figure:: ../../gallery/axes_grid1/images/sphx_glr_demo_axes_grid_001.png
   :target: ../../gallery/axes_grid1/demo_axes_grid.html
   :align: center
   :scale: 50

.. currentmodule:: mpl_toolkits

**The submodules of the axes_grid1 API are:**

.. autosummary::
   :toctree: ../_as_gen
   :template: automodule.rst

   axes_grid1.anchored_artists
   axes_grid1.axes_divider
   axes_grid1.axes_grid
   axes_grid1.axes_rgb
   axes_grid1.axes_size
   axes_grid1.colorbar
   axes_grid1.inset_locator
   axes_grid1.mpl_axes
   axes_grid1.parasite_axes


